==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Impostazioni Demone Media Player</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Indirizzo del server del Demone Media Player</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Il numero della porta MPD è in ascolto</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Scadenza connessione (secondi)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Numero di secondi prima del termine della connessione</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Impostazioni Demone Media Player</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Indirizzo del server del Demone Media Player</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Il numero della porta MPD è in ascolto</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Scadenza connessione (secondi)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Numero di secondi prima del termine della connessione</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
</TS>
